Indexable

Trait Indexable 

pub trait Indexable<Idx> {
    type Element: ?Sized;
}
place[idx] – Enable indexing into Self.

Indexing is only supported for certain places: namely those handles H, for which Self implements IndexPlace<Idx, H, _, _>.

In a way, this trait is a generic version of PlaceProxy, since indexing allows changing the type based on the type of the index.

Required Associated Types

type Element: ?Sized

The type of the place expression self[idx].

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors