PlaceHandle

Trait PlaceHandle 

pub trait PlaceHandle: Sized {
    type Target: ?Sized;
}
A handle to a place.

All place operations are carried out by handles. Whether a place operation is available depends on the handle type implementing the respective place operation trait.

Place handles are not user-facing. Instead, they and the use of their operations are emitted by the compiler as part of desugaring place expressions and place operations.

Required Associated Types

type Target: ?Sized

The type that’s stored in the place.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: ?Sized> PlaceHandle for *const T

Source

impl<T: ?Sized> PlaceHandle for *mut T

Source

impl<T: ?Sized> PlaceHandle for NonNull<T>

Implementors