PlaceProxy

Trait PlaceProxy 

pub trait PlaceProxy {
    type Target: ?Sized;
}
A type proxying for a place.

A value of this type represents a specific place. The operations that are available on that place are controlled by which place operation traits are implemented on the handle of that place, which is CreateHandle::Handle.

Required Associated Types

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, T: ?Sized> PlaceProxy for &'a T

Source

impl<'a, T: ?Sized> PlaceProxy for &'a mut T

Source

impl<'b, T> PlaceProxy for RefMut<'b, T>

Source

impl<P> PlaceProxy for Pin<P>
where P: PlaceProxy,

Source

impl<T: ?Sized> PlaceProxy for *const T

Source

impl<T: ?Sized> PlaceProxy for *mut T

Source

impl<T: ?Sized> PlaceProxy for Arc<T>

Source

impl<T: ?Sized> PlaceProxy for Box<T>

Source

impl<T: ?Sized> PlaceProxy for NonNull<T>

Source

impl<T> PlaceProxy for Vec<T>

Implementors