pub unsafe trait DropPlace: PlaceHandle {
// Required method
unsafe fn drop_place(self);
}Expand description
Drop the contents of a place.
This operation should only drop the value at the place and not invalidate
the proxy itself. A new value might be moved back in later with
WritePlace.
Calls to Self::drop_place are emitted by the compiler as part of
dropping a PlaceProxy that’s partially moved out.
Required Methods
unsafe fn drop_place(self)
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".