pub trait PlaceProxy {
type Target: ?Sized;
}Expand description
A type proxying for a place.
A value of this type represents a specific place. The operations that are
available on that place are controlled by which place operation traits are
implemented on the handle of that place, which is CreateHandle::Handle.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".