pub unsafe trait WritePlace: PlaceHandle {
const ACCESS: AccessKind;
const SAFE: bool;
// Required method
unsafe fn write_place(self, value: Self::Target);
}Expand description
place = value; – Write to a place.
Writing to a place is done by writing the place on the left hand side of an assignment expression.
Required Associated Constants
Sourceconst ACCESS: AccessKind
const ACCESS: AccessKind
The access permissions to the place required by Self::write_place.
Sourceconst SAFE: bool
const SAFE: bool
Whether Self::write_place is safe when Self::ACCESS is honored.
This constant controls whether the compiler will require writing an
unsafe block around writing to a place that uses this handle.
Required Methods
Sourceunsafe fn write_place(self, value: Self::Target)
unsafe fn write_place(self, value: Self::Target)
Write to the place.
Safety
This handle must have Self::ACCESS permissions for the duration of
this method call.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".